@@ -26,9 +26,11 @@ class client_view(object):
     This view show a client info
     '''
 
-    def __init__(self, ctrl, client=None, kind=None):
+    def __init__(self, ctrl, client=None, kind=None, c_id=None):
         '''
-        
+        c_id is the client_view identifier which could be:
+            -client.dni: for show info client
+            -#:<number>: that means new client to be inserted in the system
         '''
         self.controller = ctrl
         self.builder = gtk.Builder()
@@ -54,58 +56,57 @@ class client_view(object):
             "on_client_info_destroy" : self.quit,
             "on_cancel_clicked" : self.quit,
             "client_entry_changed" : self.entry_changed,
+            "on_apply_clicked" : self.save_apply,
               }
-        self.old_dni = ""
-        self.modified = None
-        if kind == "new":    
-            dic['on_apply_clicked'] = self.save_apply    
+        if c_id.startswith("#:"):
+            self.old_dni = ""
+            self.window.set_title("New client %s" % c_id[2])
+        else:
+            self.old_dni = c_id
+            self.window.set_title("Client with DNI: %s" % c_id)
         if client!=None:
-            dic['on_apply_clicked'] = self.to_modify 
             self.name_entry.set_text(_None_to_str(client.name))
             self.surname_entry.set_text(_None_to_str(client.surname))
-            self.old_dni = _None_to_str(client.dni)
             self.dni_entry.set_text(self.old_dni)
             self.email_entry.set_text(_None_to_str(client.email))
             self.web_entry.set_text(_None_to_str(client.web))
-            self.modified = False
-        
         self.builder.connect_signals(dic)
+        self.entry_changed = False
     
-    def to_modify(self, button):
-        if self.modified == True:
-            self.modified = False
-            self.save_apply(button, self.old_dni)
-        else:
-            self.window.hide()
-    
-    def save_apply(self, apply_button, to_update=None):
-        dni = self.dni_entry.get_text().decode('utf-8')
-        exist = self.controller.client_exist(dni)
-        if dni=="":
-            self.warning_label.set_text("Warning, dni field must be filled  ")
-            self.warning_label.show()
-        elif exist == True:
-            self.warning_label.set_text("Warning, dni already in the system")
-            self.warning_label.show()
-        else:
-            self.warning_label.hide()
-            client = models.Models.Client(self.name_entry.get_text(),
-                                      self.surname_entry.get_text(),
-                                      self.dni_entry.get_text(),
-                                      self.email_entry.get_text(),
-                                      self.web_entry.get_text(),
-                                      )
-            if to_update != None:
-                self.controller.to_modify(self.old_dni, client)
+    def save_apply(self, apply_button):
+        if self.entry_changed:
+            new_dni = self.dni_entry.get_text().decode('utf-8')
+            exist = self.controller.client_exist(new_dni)
+            if new_dni=="":
+                self.warning_label.set_text("DNI field must be filled")
+                self.warning_label.show()
+            elif new_dni[0] == "#":
+                self.warning_label.set_text("DNI not able to start with #")
+                self.warning_label.show()
+            elif (self.old_dni != new_dni and exist):
+                self.warning_label.set_text("DNI already in the system")
+                self.warning_label.show()
             else:
-                self.controller.insert_new_client(client)
-            self.controller.refresh_clients_main_view(client, old_dni=self.old_dni)
+                self.warning_label.hide()
+                client = models.Models.Client(self.name_entry.get_text(),
+                                          self.surname_entry.get_text(),
+                                          new_dni,
+                                          self.email_entry.get_text(),
+                                          self.web_entry.get_text(),
+                                          )
+                #if new_dni != self.old_dni or exist:
+                if exist:
+                    self.controller.to_modify(self.old_dni, client)
+                else:
+                    self.controller.insert_new_client(client)
+                self.controller.refresh_clients_main_view(client, old_dni=self.old_dni)
+                self.window.hide()
+        else:
             self.window.hide()
         
     def entry_changed(self, widget):
-        if self.modified == False:
-            self.modified = True
-            self.apply_button.set_label("Save")
+        self.entry_changed = True
+        self.apply_button.set_label("Save")
 
     def quit(self, widget):
         self.hide()
