@@ -32,7 +32,7 @@ class main_view(object):
         '''
         self.controller = ctrl
         self.builder = gtk.Builder()
-        self.main_window_name = "main_view"
+        self.main_window_name = "Ord-en Ley"
         glade_name = "main_view.glade"
         try:
             self.filename = views.get_data_dev(glade_name)
@@ -49,6 +49,7 @@ class main_view(object):
         
         dic = {
         "on_main_view_destroy" : self.quit,
+        "gtk_main_quit" : self.quit,
         "on_client_tree_row_activated" : self.row_activated,
         "on_new_client_clicked" : self.new_client,
         "on_delete_client_clicked" : self.delete_client,
